@@ -13,7 +13,7 @@
  *
  *
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
- * Copyright (c) 1994-1996 Marcel J.E. Mol, Rijswijk, The Netherlands
+ * Copyright (c) 1994-1997 Marcel J.E. Mol, The Netherlands
  *                    marcel@mesa.nl
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -82,18 +82,17 @@ do_args(argc, argv, envflag)
                                      UPDOWN : LEFTRIGHT;
                         break;
                 case 'A':    /* A4 sized, european paper */
-                        opt_page = PAGE_A4;
+                        opt_page = "A4";
                         break;
                 case 'b':     /* base paper type */
                         OPTARG();
-                        if (!strcasecmp(optstr, "A4"))
-                            opt_page = PAGE_A4;
-                        else if (!strcasecmp(optstr, "Letter"))
-                            opt_page = PAGE_LETTER;
-                        else if (!strcasecmp(optstr, "Legal"))
-                            opt_page = PAGE_LEGAL;
-                        else
-                            fprintf(stderr, "unkown paper type %c\n", *optstr);
+                        /* see if user wants help */
+                        if (!strcmp(optstr, "?") || !strcmp(optstr, "l")) {
+                            show_pagetypes();
+                            exit(0);
+                        }
+                        /* set opt_page */
+                        select_pagetype(optstr);
                         break;
                 case 'B': {
                         int pb = 0; /* set a default */
@@ -212,6 +211,9 @@ do_args(argc, argv, envflag)
                         if (*optstr == '/' || *optstr == '%')
                             opt_alt = atoi(++optstr);
                         break;
+                case 'k':    /* toggle kill on trailer */
+                        opt_killtrail = 1 - opt_killtrail;
+                        break;
                 case 'l':    /* landscape */
                         sheetaspect = sheetaspect == LANDSCAPE ?
                                       PORTRAIT : LANDSCAPE;
@@ -340,7 +342,7 @@ do_args(argc, argv, envflag)
                         consumed = 1;
                         doprint = 1;
                         if (*++optstr)
-                            if (!strcmp(optstr, "-"))
+                            if (*optstr == '-' && *(optstr+1) == '\0')
                                 doprint = 0; /* kill MPAGE envvar que setting*/
                             else {
                                 printque = optstr;
@@ -367,7 +369,7 @@ do_args(argc, argv, envflag)
                         opt_tumble = 1 - opt_tumble;
                         break;
                 case 'U':    /* Letter sized, US paper */
-                        opt_page = PAGE_LETTER;
+                        opt_page = "Letter";
                         break;
                 case 'v':    /* verbose (print page count) */
                         opt_verbose = 1 - opt_verbose;
@@ -397,6 +399,9 @@ do_args(argc, argv, envflag)
             }
         }
     }
+    /*
+     * Just NOW set the page size parameters
+     */
     set_page();
 
     if (opterrors)
